@@ -1,7 +1,7 @@
 import React from 'react'
 import PropTypes from 'prop-types'
 import { connect } from 'react-redux'
-import { localeCompare } from '_/helpers'
+import { localeCompare, isWindows } from '_/helpers'
 import { msg } from '_/intl'
 import { isNumberInRange } from '_/utils'
 import { BASIC_DATA_SHAPE } from '../dataPropTypes'
@@ -11,14 +11,24 @@ import {
   createIsoList,
   createOsList,
   createTemplateList,
+  getTopology,
+  getTopologyPossibleValues,
   isHostNameValid,
   isVmNameValid,
 } from '_/components/utils'
 
-import { Form, FormControl, Checkbox } from 'patternfly-react'
+import {
+  ExpandCollapse,
+  FieldLevelHelp,
+  Form,
+  FormControl,
+  Checkbox,
+} from 'patternfly-react'
 import { Grid, Row, Col } from '_/components/Grid'
 import SelectBox from '_/components/SelectBox'
 
+import timezones from '_/components/utils/timezones.json'
+
 import style from './style.css'
 
 /*
@@ -31,7 +41,10 @@ const FieldRow = ({
   rowClassName = '',
   vertical = false,
   validationState = null,
+  labelCols = 3,
+  fieldCols = 7,
   children,
+  tooltip,
 }) => (
   <Row className={`
       form-group
@@ -43,7 +56,7 @@ const FieldRow = ({
   >
     { vertical &&
       <React.Fragment>
-        <Col offset={3} cols={7} className={style['col-data']} id={id}>
+        <Col offset={labelCols} cols={fieldCols} className={style['col-data']} id={id}>
           <div className={style['col-label-vertical']}>
             {label}
           </div>
@@ -53,10 +66,16 @@ const FieldRow = ({
     }
     { !vertical &&
       <React.Fragment>
-        <Col cols={3} className={`control-label ${style['col-label']}`}>
+        <Col cols={labelCols} className={`control-label ${style['col-label']}`}>
           {label}
+          { tooltip &&
+            <FieldLevelHelp
+              content={tooltip}
+              inline
+            />
+          }
         </Col>
-        <Col cols={7} className={style['col-data']} id={id}>{children}</Col>
+        <Col cols={fieldCols} className={style['col-data']} id={id}>{children}</Col>
       </React.Fragment>
     }
   </Row>
@@ -68,7 +87,10 @@ FieldRow.propTypes = {
   rowClassName: PropTypes.string,
   vertical: PropTypes.bool,
   validationState: PropTypes.oneOf(['success', 'warning', 'error', null]),
+  labelCols: PropTypes.number,
+  fieldCols: PropTypes.number,
   children: PropTypes.node.isRequired,
+  tooltip: PropTypes.string,
 }
 
 const SubHeading = ({ children }) => (
@@ -113,9 +135,13 @@ export const optimizedForMap = {
 class BasicSettings extends React.Component {
   constructor (props) {
     super(props)
+    this.checkTimeZone = this.checkTimeZone.bind(this)
+    this.getTopologySettings = this.getTopologySettings.bind(this)
     this.handleChange = this.handleChange.bind(this)
     this.validateForm = this.validateForm.bind(this)
     this.validateVmName = this.validateVmName.bind(this)
+    this.mapVCpuTopologyItems = this.mapVCpuTopologyItems.bind(this)
+    this.handleProvisionSourceChange = this.handleProvisionSourceChange.bind(this)
 
     this.fields = {
       select: [
@@ -127,6 +153,35 @@ class BasicSettings extends React.Component {
     }
   }
 
+  checkTimeZone (osId, templateId) {
+    const { defaultGeneralTimezone, defaultWindowsTimezone } = this.props
+    const template = templateId ? this.props.templates.get(templateId) : undefined
+
+    let timeZone = {
+      name: defaultGeneralTimezone,
+    }
+    const osType = this.props.operatingSystems.getIn([ osId, 'name' ])
+
+    if (template && template.getIn(['timeZone', 'name'])) {
+      timeZone = template.get('timeZone').toJS()
+    }
+
+    const isWindowsTimeZone = timeZone && timezones.find(timezone => timezone.id === timeZone.name)
+    const isWindowsVm = isWindows(osType)
+
+    if (isWindowsVm && !isWindowsTimeZone) {
+      timeZone = {
+        name: defaultWindowsTimezone,
+      }
+    }
+    if (!isWindowsVm && isWindowsTimeZone) {
+      timeZone = {
+        name: defaultGeneralTimezone,
+      }
+    }
+    return timeZone
+  }
+
   validateForm (dataSet) {
     const {
       dataCenters, clusters, storageDomains, templates, operatingSystems,
@@ -167,7 +222,44 @@ class BasicSettings extends React.Component {
 
   validateVmName () {
     const name = this.props.data.name
-    return name === undefined || name.length === 0 || isVmNameValid(name) ? null : 'error'
+    return name === undefined || name.length === 0 || !isVmNameValid(name) ? 'error' : null
+  }
+
+  // Calculate the proper number of virtual sockets, cores per virtual socket, threads per core according to the number of virtual CPUs
+  // any change of the number of vCpus in the Basic settings requires recalculation of the numer of cores, sockets, threads
+  getTopologySettings (vcpus, force = {}) {
+    return getTopology({
+      value: vcpus,
+      max: {
+        sockets: this.props.maxNumOfSockets,
+        cores: this.props.maxNumOfCores,
+        threads: this.props.maxNumOfThreads,
+      },
+      force: force,
+    })
+  }
+
+  handleProvisionSourceChange (provisionSource) {
+    const changes = {}
+    const { defaultValues } = this.props
+
+    changes.provisionSource = provisionSource
+    changes.isoImage = undefined
+    changes.templateId = undefined
+    changes.operatingSystemId = defaultValues.operatingSystemId
+    changes.memory = defaultValues.memory
+    changes.cpus = defaultValues.cpus
+    changes.topology = defaultValues.topology
+    changes.optimizedFor = defaultValues.optimizedFor
+    changes.cloudInitEnabled = defaultValues.initEnabled
+
+    // when changing Provision type to ISO, set the default time zone according to the OS
+    if (changes.provisionSource === 'iso') {
+      changes.timeZone = this.checkTimeZone(changes.operatingSystemId, changes.templateId)
+      changes.initTimezone = '' // reset the sysprep timezone value, we don't support cloud-init TZ yet
+    }
+
+    return changes
   }
 
   handleChange (field, value, extra) {
@@ -181,51 +273,37 @@ class BasicSettings extends React.Component {
       value = !!value || value === 'on'
     }
 
-    const changes = {}
+    let changes = {}
     switch (field) {
       case 'clusterId':
-        if (value === undefined) {
-          changes.dataCenterId = undefined
-          changes.clusterId = undefined
-          changes.provisionSource = 'template'
-          changes.isoImage = undefined
-          changes.templateId = undefined
-        } else {
-          const templateList = createTemplateList(this.props.templates, value)
-
-          changes.dataCenterId = this.props.clusters.getIn([value, 'dataCenterId'])
-          changes.clusterId = value
-          changes.provisionSource =
+        const templateList = value ? createTemplateList(this.props.templates, value) : []
+        changes.dataCenterId = value ? this.props.clusters.getIn([value, 'dataCenterId']) : undefined
+        changes.clusterId = value
+        changes.provisionSource =
             (templateList.length === 1 && templateList[0].id === this.props.blankTemplateId)
               ? 'iso'
               : 'template'
-          changes.isoImage = undefined
-          changes.templateId = templateList.length === 1 ? this.props.blankTemplateId : undefined
-        }
+        changes.templateId = templateList.length === 1 ? this.props.blankTemplateId : undefined
+        changes = { ...changes, ...this.handleProvisionSourceChange(changes.provisionSource) }
         break
 
       case 'provisionSource':
-        changes.provisionSource = value
-        changes.isoImage = undefined
-        changes.templateId = undefined
-        changes.operatingSystemId = this.props.defaultValues.operatingSystemId
-        changes.memory = this.props.defaultValues.memory
-        changes.cpus = this.props.defaultValues.cpus
-        changes.optimizedFor = this.props.defaultValues.optimizedFor
-        changes.cloudInitEnabled = this.props.defaultValues.initEnabled
+        changes = this.handleProvisionSourceChange(value)
         break
 
       case 'templateId':
         const template = this.props.templates.find(t => t.get('id') === value)
         changes.templateId = template.get('id')
-
         changes.memory = template.get('memory') / (1024 ** 2) // stored in bytes, input in Mib
         changes.cpus = template.getIn([ 'cpu', 'vCPUs' ])
+        changes.topology = template.getIn([ 'cpu', 'topology' ]).toJS()
         changes.optimizedFor = template.get('type', this.props.data.optimizedFor)
         changes.operatingSystemId = this.props.operatingSystems
           .find(os => os.get('name') === template.getIn([ 'os', 'type' ]))
           .get('id')
 
+        // Check template's timezone compatibility with the template's OS, set the timezone corresponding to the template's OS
+        changes.timeZone = this.checkTimeZone(changes.operatingSystemId, changes.templateId)
         changes.cloudInitEnabled = template.getIn(['cloudInit', 'enabled'])
         changes.initHostname = template.getIn(['cloudInit', 'hostName'])
         changes.initSshKeys = template.getIn(['cloudInit', 'sshAuthorizedKeys'])
@@ -233,6 +311,11 @@ class BasicSettings extends React.Component {
         changes.initCustomScript = template.getIn(['cloudInit', 'customScript'])
         break
 
+      case 'operatingSystemId':
+        changes[field] = value
+        changes.timeZone = this.checkTimeZone(value, this.props.data.templateId)
+        break
+
       case 'memory':
         if (isNumberInRange(value, 0, this.props.maxMemorySizeInMiB)) {
           changes.memory = +value
@@ -243,6 +326,12 @@ class BasicSettings extends React.Component {
         if (isNumberInRange(value, 0, this.props.maxNumOfVmCpus)) {
           changes.cpus = +value
         }
+
+        changes.topology = this.getTopologySettings(changes.cpus)
+        break
+
+      case 'topology': // number of sockets, cores or threads changed by the user in Advanced Options section
+        changes[field] = this.getTopologySettings(this.props.data.cpus, { [extra.vcpu]: +value })
         break
 
       default:
@@ -255,18 +344,33 @@ class BasicSettings extends React.Component {
     }
   }
 
+  mapVCpuTopologyItems (items) {
+    return items.map(i =>
+      ({
+        id: i.toString(),
+        value: i.toString(),
+      })
+    )
+  }
+
   render () {
     const idPrefix = this.props.id || 'create-vm-wizard-basic'
-    const data = this.props.data
+    const { data, clusters, maxNumOfSockets, maxNumOfCores, maxNumOfThreads } = this.props
+    const indicators = {
+      name: this.validateVmName(),
+    }
 
     const clusterList =
-      createClusterList(this.props.clusters)
+      createClusterList(clusters)
         .map(cluster => ({
           id: cluster.id,
           value: `${cluster.value} (${this.props.dataCenters.find(dc => dc.id === cluster.datacenter).name})`,
         }))
     if (!isValidUid(data.clusterId)) {
       clusterList.unshift({ id: '_', value: `-- ${msg.createVmWizardSelectCluster()} --` })
+      indicators.cluster = !indicators.name && 'error'
+    } else {
+      delete indicators.cluster
     }
 
     const provisionSourceList =
@@ -276,11 +380,14 @@ class BasicSettings extends React.Component {
       ]
     if (!isValidSource(data.provisionSource)) {
       provisionSourceList.unshift({ id: '_', value: `-- ${msg.createVmWizardSelectProvisionSource()} --` })
+      indicators.provisionSource = !indicators.cluster && 'error'
+    } else {
+      delete indicators.provisionSource
     }
 
     const enableOsSelect = isValidUid(data.clusterId) && [ 'iso', 'template' ].includes(data.provisionSource)
     const operatingSystemList = enableOsSelect
-      ? createOsList(data.clusterId, this.props.clusters, this.props.operatingSystems)
+      ? createOsList(data.clusterId, clusters, this.props.operatingSystems)
       : [ { id: '_', value: `-- ${msg.createVmWizardSelectClusterBeforeOS()} --` } ]
 
     const enableIsoSelect = data.provisionSource === 'iso' && isValidUid(data.dataCenterId)
@@ -294,6 +401,9 @@ class BasicSettings extends React.Component {
       : [ { id: '_', value: `-- ${msg.createVmWizardSelectClusterBeforeISO()} --` } ]
     if (enableIsoSelect && !isValidUid(data.isoImage)) {
       isoList.unshift({ id: '_', value: `-- ${msg.createVmWizardSelectISO()} --` })
+      indicators.isoList = !indicators.provisionSource && !indicators.name && 'error'
+    } else {
+      delete indicators.isoList
     }
 
     const enableTemplateSelect = data.provisionSource === 'template'
@@ -302,16 +412,33 @@ class BasicSettings extends React.Component {
       : [ { id: '_', value: `-- ${msg.createVmWizardSelectClusterBeforeTemplate()} --` } ]
     if (enableTemplateSelect && isValidUid(data.clusterId) && !isValidUid(data.templateId)) {
       templateList.unshift({ id: '_', value: `-- ${msg.createVmWizardSelectTemplate()} --` })
+      indicators.template = !indicators.provisionSource && !indicators.name && 'error'
+    } else {
+      delete indicators.template
     }
 
     const enableCloudInit = data.cloudInitEnabled && isOsLinux(data.operatingSystemId, this.props.operatingSystems)
     const enableSysPrep = data.cloudInitEnabled && isOsWindows(data.operatingSystemId, this.props.operatingSystems)
 
+    // for Advanced CPU Topology Options expand/collapse section
+    const vCpuTopologyDividers = getTopologyPossibleValues({
+      value: data.cpus,
+      maxNumberOfSockets: maxNumOfSockets,
+      maxNumberOfCores: maxNumOfCores,
+      maxNumberOfThreads: maxNumOfThreads,
+    })
+    // for Threads per Core tooltip
+    const clusterId = data.clusterId || '_'
+    const cluster = clusters && clusters.get(clusterId)
+    const threadsTooltip = cluster && cluster.get('architecture') === 'ppc64'
+      ? msg.recomendedPower8ValuesForThreads({ threads: maxNumOfThreads })
+      : msg.recomendedValuesForThreads({ threads: maxNumOfThreads })
+
     // ----- RENDER -----
     return <Form horizontal id={idPrefix}>
       <Grid className={style['settings-container']}>
         {/* -- VM name and where it will live -- */}
-        <FieldRow label={msg.name()} id={`${idPrefix}-name`} required validationState={this.validateVmName()}>
+        <FieldRow label={msg.name()} id={`${idPrefix}-name`} required validationState={indicators.name}>
           <FormControl
             id={`${idPrefix}-name-edit`}
             autoComplete='off'
@@ -336,6 +463,7 @@ class BasicSettings extends React.Component {
             items={clusterList}
             selected={data.clusterId || '_'}
             onChange={selectedId => this.handleChange('clusterId', selectedId)}
+            validationState={indicators.cluster}
           />
         </FieldRow>
 
@@ -357,6 +485,7 @@ class BasicSettings extends React.Component {
               items={isoList}
               selected={data.isoImage || '_'}
               onChange={selectedId => this.handleChange('isoImage', selectedId)}
+              validationState={indicators.isoList}
             />
           </FieldRow>
         }
@@ -369,6 +498,7 @@ class BasicSettings extends React.Component {
               items={templateList}
               selected={data.templateId || '_'}
               onChange={selectedId => this.handleChange('templateId', selectedId)}
+              validationState={indicators.template}
             />
           </FieldRow>
         }
@@ -393,7 +523,6 @@ class BasicSettings extends React.Component {
           />
         </FieldRow>
 
-        {/* TODO: Add CPU topology setup like in Details card */}
         <FieldRow label={msg.cpus()} id={`${idPrefix}-cpus`} required>
           <FormControl
             id={`${idPrefix}-cpus-edit`}
@@ -474,13 +603,12 @@ class BasicSettings extends React.Component {
               />
             </FieldRow>
 
-            {/* TODO: Swap out for a proper timezone drop down once PR #1004 is merged */}
             <FieldRow label={msg.sysPrepTimezone()} id={`${idPrefix}-sysPrepTimezone`} vertical>
-              <FormControl
-                id={`${idPrefix}-sysPrepTimezone-edit`}
-                type='text'
-                defaultValue={data.initTimezone}
-                onChange={e => this.handleChange('initTimezone', e.target.value)}
+              <SelectBox
+                id={`${idPrefix}-sysprep-timezone-select`}
+                items={timezones}
+                selected={data.initTimezone}
+                onChange={selectedId => this.handleChange('initTimezone', selectedId)}
               />
             </FieldRow>
 
@@ -505,6 +633,41 @@ class BasicSettings extends React.Component {
           </React.Fragment>
         }
       </Grid>
+
+      {/* Advanced CPU Topology Options */}
+      <ExpandCollapse id={`${idPrefix}-advanced-options`} textCollapsed={msg.advancedCpuTopologyOptions()} textExpanded={msg.advancedCpuTopologyOptions()}>
+        <Grid className={style['settings-container']}>
+          <FieldRow fieldCols={3} label={msg.virtualSockets()} id={`${idPrefix}-topology-sockets`}>
+            <SelectBox
+              id={`${idPrefix}-topology-sockets-edit`}
+              items={this.mapVCpuTopologyItems(vCpuTopologyDividers.sockets)}
+              selected={data.topology.sockets.toString()}
+              onChange={selectedId => { this.handleChange('topology', selectedId, { vcpu: 'sockets' }) }}
+            />
+          </FieldRow>
+          <FieldRow fieldCols={3} label={msg.coresPerSockets()} id={`${idPrefix}-topology-cores`}>
+            <SelectBox
+              id={`${idPrefix}-topology-cores-edit`}
+              items={this.mapVCpuTopologyItems(vCpuTopologyDividers.cores)}
+              selected={data.topology.cores.toString()}
+              onChange={selectedId => { this.handleChange('topology', selectedId, { vcpu: 'cores' }) }}
+            />
+          </FieldRow>
+          <FieldRow
+            fieldCols={3}
+            label={msg.threadsPerCores()}
+            id={`${idPrefix}-topology-threads`}
+            tooltip={threadsTooltip}
+          >
+            <SelectBox
+              id={`${idPrefix}-topology-threads-edit`}
+              items={this.mapVCpuTopologyItems(vCpuTopologyDividers.threads)}
+              selected={data.topology.threads.toString()}
+              onChange={selectedId => { this.handleChange('topology', selectedId, { vcpu: 'threads' }) }}
+            />
+          </FieldRow>
+        </Grid>
+      </ExpandCollapse>
     </Form>
   }
 }
@@ -523,7 +686,14 @@ BasicSettings.propTypes = {
   maxNumOfVmCpus: PropTypes.number.isRequired,
   maxMemorySizeInMiB: PropTypes.number.isRequired,
 
+  maxNumOfSockets: PropTypes.number.isRequired,
+  maxNumOfCores: PropTypes.number.isRequired,
+  maxNumOfThreads: PropTypes.number.isRequired,
+
   onUpdate: PropTypes.func.isRequired,
+
+  defaultGeneralTimezone: PropTypes.string.isRequired,
+  defaultWindowsTimezone: PropTypes.string.isRequired,
 }
 
 export default connect(
@@ -536,5 +706,10 @@ export default connect(
     storageDomains: state.storageDomains,
     maxNumOfVmCpus: state.config.get('maxNumOfVmCpus', 384),
     maxMemorySizeInMiB: 4194304, // TODO: 4TiB, no config option pulled as of 2019-Mar-22
+    defaultGeneralTimezone: state.config.get('defaultGeneralTimezone'),
+    defaultWindowsTimezone: state.config.get('defaultWindowsTimezone'),
+    maxNumOfSockets: state.config.get('maxNumberOfSockets'),
+    maxNumOfCores: state.config.get('maxNumberOfCores'),
+    maxNumOfThreads: state.config.get('maxNumberOfThreads'),
   })
 )(BasicSettings)
