@@ -2,13 +2,14 @@ import React from 'react'
 import PropTypes from 'prop-types'
 import { connect } from 'react-redux'
 import { msg } from '_/intl'
-import { localeCompare, generateUnique } from '_/helpers'
+import { generateUnique } from '_/helpers'
 import { isNumber, convertValue } from '_/utils'
 import { BASIC_DATA_SHAPE, STORAGE_SHAPE } from '../dataPropTypes'
 
 import {
   createDiskTypeList,
   createStorageDomainList,
+  sortNicsDisks,
   suggestDiskName,
 } from '_/components/utils'
 
@@ -18,6 +19,7 @@ import {
   DropdownKebab,
   EmptyState,
   FieldLevelHelp,
+  FormGroup,
   FormControl,
   MenuItem,
   Table,
@@ -239,15 +241,24 @@ class Storage extends React.Component {
         editView: (value, { rowData }) => {
           const row = this.state.editing[rowData.id]
           const sizeGiB = row.size / (1024 ** 3)
+          const { invalidSizeValue } = row
 
           return <div className={style['disk-size-edit']}>
-            <FormControl
-              id={`${idPrefix}-${value}-size-edit`}
-              type='number'
-              defaultValue={sizeGiB}
-              className={style['disk-size-form-control-edit']}
-              onBlur={e => this.handleCellChange(rowData, 'size', e.target.value)}
-            />
+            <FormGroup
+              validationState={invalidSizeValue && 'error'}
+              className={style['form-group-edit']}
+            >
+              <FormControl
+                id={`${idPrefix}-${value}-size-edit`}
+                type='number'
+                min={this.props.minDiskSizeInGiB}
+                max={this.props.maxDiskSizeInGiB}
+                step={1}
+                value={sizeGiB}
+                className={style['disk-size-form-control-edit']}
+                onChange={e => this.handleCellChange(rowData, 'size', e.target.value)}
+              />
+            </FormGroup>
             <span className={style['disk-size-edit-label']}>GiB</span>
             <FieldLevelHelp
               inline
@@ -437,9 +448,17 @@ class Storage extends React.Component {
 
   onCreateDisk () {
     const newId = generateUnique('NEW_')
+    const {
+      minDiskSizeInGiB: diskInitialSizeInGib,
+      storageDomains,
+      dataCenterId,
+      vmName,
+      disks,
+      optimizedFor,
+    } = this.props
 
     // If only 1 storage domain is available, select it automatically
-    const storageDomainList = createStorageDomainList(this.props.storageDomains, this.props.dataCenterId)
+    const storageDomainList = createStorageDomainList(storageDomains, dataCenterId)
     const storageDomainId = storageDomainList.length === 1 ? storageDomainList[0].id : '_'
 
     // Setup a new disk in the editing hash
@@ -449,7 +468,7 @@ class Storage extends React.Component {
         ...state.editing,
         [newId]: {
           id: newId,
-          name: suggestDiskName(this.props.vmName, this.props.disks),
+          name: suggestDiskName(vmName, disks),
 
           diskId: '_',
           storageDomainId,
@@ -457,12 +476,13 @@ class Storage extends React.Component {
           bootable: false,
           iface: 'virtio_scsi',
           type: 'image',
-          diskType: getDefaultDiskType(this.props.optimizedFor),
+          diskType: getDefaultDiskType(optimizedFor),
 
-          size: 0,
+          size: (diskInitialSizeInGib * 1024 ** 3),
         },
       },
     }))
+    this.props.onUpdate({ valid: false })
   }
 
   onEditDisk (rowData) {
@@ -472,6 +492,7 @@ class Storage extends React.Component {
         [rowData.id]: rowData,
       },
     }))
+    this.props.onUpdate({ valid: false })
   }
 
   onDeleteRow (rowData) {
@@ -479,13 +500,19 @@ class Storage extends React.Component {
   }
 
   handleCellChange (rowData, field, value) {
+    const editingRow = this.state.editing[rowData.id]
     if (field === 'size') {
-      if (isNumber(value) && value > 0 && value <= this.props.maxDiskSizeInGiB) {
-        value = +value * (1024 ** 3) // GiB to B
+      if (!isNumber(value)) return
+
+      const { minDiskSizeInGiB, maxDiskSizeInGiB } = this.props
+      if (value >= minDiskSizeInGiB && value <= maxDiskSizeInGiB) {
+        delete editingRow.invalidSizeValue
+      } else {
+        editingRow.invalidSizeValue = true
       }
+      value = +value * (1024 ** 3) // GiB to B
     }
 
-    const editingRow = this.state.editing[rowData.id]
     if (editingRow) {
       editingRow[field] = value
       this.setState(state => ({
@@ -502,6 +529,8 @@ class Storage extends React.Component {
     const actionCreate = !!this.state.creating && this.state.creating === rowData.id
     const editedRow = this.state.editing[rowData.id]
 
+    if (editedRow.invalidSizeValue) return
+
     // if the edited disk is set bootable, make sure to remove bootable from the other disks
     if (editedRow.bootable) {
       const previousBootableDisk = this.props.disks.find(disk => disk.bootable)
@@ -520,6 +549,7 @@ class Storage extends React.Component {
 
   // Cancel the creation or editing of a row by throwing out edit state
   handleRowCancelChange (rowData) {
+    this.components = undefined
     this.setState(state => {
       const editing = state.editing
       delete editing[rowData.id]
@@ -528,6 +558,7 @@ class Storage extends React.Component {
         editing,
       }
     })
+    this.props.onUpdate({ valid: true })
   }
 
   // Create props for each row that will be passed to the row component (TableInlineEditRow)
@@ -558,9 +589,10 @@ class Storage extends React.Component {
     const filteredStorageDomainList = createStorageDomainList(storageDomains, dataCenterId)
     const enableCreate = storageDomainList.length > 0 && !this.isEditingMode()
 
-    const diskList = disks
+    const diskList = sortNicsDisks([...disks])
       .concat(this.state.creating ? [ this.state.editing[this.state.creating] ] : [])
       .map(disk => {
+        disk = this.state.editing[disk.id] ? this.state.editing[disk.id] : disk // update editing changes from state after sorting
         const sd = storageDomainList.find(sd => sd.id === disk.storageDomainId)
         const isSdOk = sd && filteredStorageDomainList.find(filtered => filtered.id === sd.id) !== undefined
 
@@ -578,11 +610,12 @@ class Storage extends React.Component {
               : disk.diskType,
         }
       })
-      .sort((a, b) => // template based then by name
-        a.isFromTemplate && !b.isFromTemplate ? -1
-          : !a.isFromTemplate && b.isFromTemplate ? 1
-            : localeCompare(a.name, b.name)
-      )
+    const components = {
+      body: {
+        row: _TableInlineEditRow, // Table.InlineEditRow,
+      },
+    }
+    this.components = this.components || components // if the table should (re)render the value of this.components should be undefined
 
     return <div className={style['settings-container']} id={idPrefix}>
       { diskList.length === 0 && <React.Fragment>
@@ -612,11 +645,7 @@ class Storage extends React.Component {
             dataTable
             inlineEdit
             columns={this.columns}
-            components={{
-              body: {
-                row: _TableInlineEditRow, // Table.InlineEditRow,
-              },
-            }}
+            components={this.components}
           >
             <Table.Header />
             <Table.Body
@@ -643,7 +672,7 @@ Storage.propTypes = {
   cluster: PropTypes.object.isRequired,
   storageDomains: PropTypes.object.isRequired,
   maxDiskSizeInGiB: PropTypes.number.isRequired,
-
+  minDiskSizeInGiB: PropTypes.number.isRequired,
   onUpdate: PropTypes.func.isRequired,
 }
 
@@ -652,5 +681,6 @@ export default connect(
     cluster: state.clusters.get(clusterId),
     storageDomains: state.storageDomains,
     maxDiskSizeInGiB: 4096, // TODO: 4TiB, no config option pulled as of 2019-Mar-22
+    minDiskSizeInGiB: 1,
   })
 )(Storage)
