@@ -18,9 +18,11 @@ export const messages: { [messageId: string]: MessageType } = {
     message: 'About',
     description: 'About application',
   },
+  aboutDialogApiVersion: '{brandName} API Version {version}',
   aboutDialogDocumentationLink: 'For further information see {link}',
   aboutDialogDocumentationText: 'Documentation',
   aboutDialogReportIssuesLink: 'Please report issues on {link}',
+  aboutDialogVersion: 'Version {version}',
   actionFailed: '{action} failed',
   actionFeedbackShutdownVm: 'Request to shutdown VM - {VmName} has been received.',
   actionFeedbackRestartVm: 'Request to restart VM - {VmName} has been received.',
@@ -37,6 +39,7 @@ export const messages: { [messageId: string]: MessageType } = {
     message: 'Advanced Options',
     description: 'Label used on forms when there are a set of fields that are initially hidden and require a click to view.',
   },
+  advancedCpuTopologyOptions: 'Advanced CPU Topology Options',
   alias: {
     message: 'Alias',
     description: 'In sense of "human friendly name"',
@@ -119,7 +122,6 @@ export const messages: { [messageId: string]: MessageType } = {
   createVmNetEmptyInfo: 'No NICs have been defined for this VM.',
   createVmNetEmptyTitle: 'No NICs Defined',
   createVmNetNoEditHelpMessage: 'This NIC is defined by your selected template and cannot be edited or deleted at creation.',
-  createVmNetSelectVnicProfile: 'Select vNic Profile',
   createVmNetTableHeaderNicName: 'NIC Name',
   createVmNetTableHeaderType: 'Device Type',
   createVmNetTableHeaderVnicProfile: 'vNic Profile',
@@ -163,6 +165,7 @@ export const messages: { [messageId: string]: MessageType } = {
   createVmWizardStepTitleNetwork: 'Networking',
   createVmWizardStepTitleReview: 'Review',
   createVmWizardStepTitleStorage: 'Storage',
+  createVmWizardNetVNICNameRules: 'NIC name must be unique, 50 or less alphanumeric characters or "-_."',
   currentlyInsertedIsoInCdDrive: 'Currently inserted ISO in CD drive',
   customIcon: 'Custom icon of the virtual machine.',
   customScript: 'Custom script',
@@ -499,7 +502,7 @@ export const messages: { [messageId: string]: MessageType } = {
   rebootVm: 'Reboot the VM',
   rebootVmQuestion: 'Are you sure you want to Restart the VM?',
   recomendedPower8ValuesForThreads: 'Your cluster architecture is POWER, we recommend using 1 through {threads} values ({threads} for high load VMs).',
-  recomendedValuesForThreads: 'Please check your host architecture to make sure it is properly set up before changing the value. If you are not sure, we recommend keeping threads-per-core set to 1. Other recommended values include: x86- 1, Power8- 1 through {threads} ({threads} for high load VMs).',
+  recomendedValuesForThreads: 'Please check your host architecture to make sure it is properly set up before changing the value. If you are not sure, we recommend keeping threads-per-core set to 1.',
   refresh: {
     message: 'Refresh',
     description: 'Reload data from server',
@@ -610,6 +613,10 @@ export const messages: { [messageId: string]: MessageType } = {
   upload: 'Upload',
   uploadIconFilesizeTooLarge: 'Image size should be {maxIconSize} KiB or less.',
   uploadIconNotImage: 'Icon should be an image.',
+  uptimeDuration: {
+    message: '(up {uptime})',
+    description: 'contain a VM\'s formatted uptime duration string',
+  },
   utilization: { message: 'Utilization', description: 'Title of Utilization card on VM Details' },
   utilizationCardAllocated: 'Allocated',
   utilizationCardAvailable: 'Available',
